# Foo

## Living Standard, 1 January 1970

This version:
  http://example.com/foo
Editor:
  Example Editor

COPYRIGHT GOES HERE

## Abstract

Testing bibliography generation.

[NON-NORMATIVE]

[NORMATIVE]

[NO-AUTHOR]

[STRING-BASED]

[ALIAS-OF-SOMETHING-ELSE]

some different text

## References

### Normative References

[NORMATIVE]
  alice; bob. Bar Level 1. REC. URL: https://example.test/bar/

### Informative References

[ALIAS-OF-SOMETHING-ELSE]
  I'm something else string-based.
[NO-AUTHOR]
  Baz Level 1. REC. URL: https://example.test/baz/
[NON-NORMATIVE]
  bar; baz. Foo Level 1. REC. URL: https://example.test/foo/
[STRING-BASED]
  I'm made out of unstructured text, oh no!